@@ -28,9 +28,14 @@ from .discovery.files import (
     ASSDiscovery,
     FluentDiscovery,
     GettextDiscovery,
+    HTMLDiscovery,
+    IDMLDiscovery,
+    INIDiscovery,
+    InnoSetupDiscovery,
     JavaDiscovery,
     JoomlaDiscovery,
     JSONDiscovery,
+    ODFDiscovery,
     OSXDiscovery,
     PHPDiscovery,
     QtDiscovery,
@@ -52,9 +57,14 @@ BACKENDS = [
     ASSDiscovery,
     FluentDiscovery,
     GettextDiscovery,
+    HTMLDiscovery,
+    IDMLDiscovery,
+    INIDiscovery,
+    InnoSetupDiscovery,
     JavaDiscovery,
     JoomlaDiscovery,
     JSONDiscovery,
+    ODFDiscovery,
     OSXDiscovery,
     PHPDiscovery,
     QtDiscovery,
