@@ -25,7 +25,7 @@ from itertools import chain
 from ruamel.yaml import YAML
 from ruamel.yaml.error import YAMLError, YAMLFutureWarning
 
-from .base import BaseDiscovery, EncodingDiscovery
+from .base import BaseDiscovery, EncodingDiscovery, MonoTemplateDiscovery
 
 
 class GettextDiscovery(BaseDiscovery):
@@ -72,13 +72,7 @@ class XliffDiscovery(BaseDiscovery):
     """XLIFF files discovery."""
 
     file_format = "xliff"
-    mask = "*.xliff"
-
-    def filter_files(self):
-        """Filters possible file matches."""
-        return chain(
-            self.finder.filter_files(self.mask), self.finder.filter_files("*.xlf")
-        )
+    mask = ("*.xliff", "*.xlf")
 
 
 class JoomlaDiscovery(BaseDiscovery):
@@ -272,13 +266,7 @@ class YAMLDiscovery(BaseDiscovery):
     """YAML files discovery."""
 
     file_format = "yaml"
-    mask = "*.yml"
-
-    def filter_files(self):
-        """Filters possible file matches."""
-        return chain(
-            self.finder.filter_files(self.mask), self.finder.filter_files("*.yaml")
-        )
+    mask = ("*.yml", "*.yaml")
 
     def adjust_format(self, result):
         if "template" not in result:
@@ -304,28 +292,28 @@ class YAMLDiscovery(BaseDiscovery):
                     result["file_format"] = "ruby-yaml"
 
 
-class SRTDiscovery(BaseDiscovery):
+class SRTDiscovery(MonoTemplateDiscovery):
     """SRT subtitle files discovery."""
 
     file_format = "srt"
     mask = "*.srt"
 
 
-class SUBDiscovery(BaseDiscovery):
+class SUBDiscovery(MonoTemplateDiscovery):
     """SUB subtitle files discovery."""
 
     file_format = "sub"
     mask = "*.sub"
 
 
-class ASSDiscovery(BaseDiscovery):
+class ASSDiscovery(MonoTemplateDiscovery):
     """ASS subtitle files discovery."""
 
     file_format = "ass"
     mask = "*.ass"
 
 
-class SSADiscovery(BaseDiscovery):
+class SSADiscovery(MonoTemplateDiscovery):
     """SSA subtitle files discovery."""
 
     file_format = "ssa"
@@ -337,3 +325,38 @@ class PHPDiscovery(BaseDiscovery):
 
     file_format = "php"
     mask = "*.php"
+
+
+class IDMLDiscovery(MonoTemplateDiscovery):
+    """IDML files discovery."""
+
+    file_format = "idml"
+    mask = "*.idml"
+
+
+class HTMLDiscovery(MonoTemplateDiscovery):
+    """HTML files discovery."""
+
+    file_format = "html"
+    mask = ("*.html", "*.htm")
+
+
+class ODFDiscovery(MonoTemplateDiscovery):
+    """ODF files discovery."""
+
+    file_format = "odf"
+    mask = ("*.odt", "*.ods", "*.odp")
+
+
+class INIDiscovery(BaseDiscovery):
+    """INI files discovery."""
+
+    file_format = "ini"
+    mask = "*.ini"
+
+
+class InnoSetupDiscovery(BaseDiscovery):
+    """InnoSetup files discovery."""
+
+    file_format = "islu"
+    mask = "*.islu"
